You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@directory.apache.org by sm...@apache.org on 2017/04/28 12:57:05 UTC

[2/2] directory-fortress-core git commit: code comments clearly describe that the truststore is now found on classpath and not fully qualified.

code comments clearly describe  that the truststore is now found on classpath and not fully qualified.


Project: http://git-wip-us.apache.org/repos/asf/directory-fortress-core/repo
Commit: http://git-wip-us.apache.org/repos/asf/directory-fortress-core/commit/49ca3252
Tree: http://git-wip-us.apache.org/repos/asf/directory-fortress-core/tree/49ca3252
Diff: http://git-wip-us.apache.org/repos/asf/directory-fortress-core/diff/49ca3252

Branch: refs/heads/master
Commit: 49ca3252076f6d5679f74b8e920a4d7a2ca8b9a6
Parents: d42482c
Author: Shawn McKinney <sm...@apache.org>
Authored: Thu Apr 27 22:45:01 2017 -0500
Committer: Shawn McKinney <sm...@apache.org>
Committed: Thu Apr 27 22:45:01 2017 -0500

----------------------------------------------------------------------
 build.properties.example                                       | 2 +-
 slapd.properties.example                                       | 2 +-
 .../fortress/core/ldap/LdapClientTrustStoreManager.java        | 6 +++---
 3 files changed, 5 insertions(+), 5 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/directory-fortress-core/blob/49ca3252/build.properties.example
----------------------------------------------------------------------
diff --git a/build.properties.example b/build.properties.example
index 255c2dd..23d3282 100644
--- a/build.properties.example
+++ b/build.properties.example
@@ -58,7 +58,7 @@ ldap.port=10389
 #ldap.host=fortressdemo2.com
 #ldap.port=10636
 #enable.ldap.ssl.debug=true
-# The trust store is picked up off the classpath:
+# The trust store is picked up off the classpath i.e. fortress-home/config:
 #trust.store=mytruststore
 #trust.store.password=changeit
 #trust.store.set.prop=true

http://git-wip-us.apache.org/repos/asf/directory-fortress-core/blob/49ca3252/slapd.properties.example
----------------------------------------------------------------------
diff --git a/slapd.properties.example b/slapd.properties.example
index 9463c1a..8ca4384 100644
--- a/slapd.properties.example
+++ b/slapd.properties.example
@@ -84,7 +84,7 @@ log.ops=logops bind writes compare
 #ldap.host=fortressdemo2.com
 #ldap.port=10636
 #enable.ldap.ssl.debug=true
-# The trust store is picked up off the classpath:
+# The trust store is picked up off the classpath i.e. fortress-home/config:
 #trust.store=mytruststore
 #trust.store.password=changeit
 #trust.store.set.prop=true

http://git-wip-us.apache.org/repos/asf/directory-fortress-core/blob/49ca3252/src/main/java/org/apache/directory/fortress/core/ldap/LdapClientTrustStoreManager.java
----------------------------------------------------------------------
diff --git a/src/main/java/org/apache/directory/fortress/core/ldap/LdapClientTrustStoreManager.java b/src/main/java/org/apache/directory/fortress/core/ldap/LdapClientTrustStoreManager.java
index 8bf224d..040ca07 100644
--- a/src/main/java/org/apache/directory/fortress/core/ldap/LdapClientTrustStoreManager.java
+++ b/src/main/java/org/apache/directory/fortress/core/ldap/LdapClientTrustStoreManager.java
@@ -68,7 +68,7 @@ public final class LdapClientTrustStoreManager implements X509TrustManager, Seri
     /**
      * Constructor used by connection configuration utility to load trust store manager.
      *
-     * @param trustStoreFile    contains fully qualified name of trust store file.
+     * @param trustStoreFile    contains name of trust store file.
      * @param trustStorePw      contains the password for trust store
      * @param trustStoreFormat  contains the format for trust store
      * @param isExamineValidity boolean var determines if certificate will be examined for valid dates on load.
@@ -82,7 +82,7 @@ public final class LdapClientTrustStoreManager implements X509TrustManager, Seri
             throw new CfgRuntimeException( GlobalErrIds.FT_CONFIG_JSSE_TRUSTSTORE_NULL,
                 "LdapClientTrustStoreManager constructor : input file name is null" );
         }
         // contains the fully-qualified file name of a valid JSSE TrustStore on local file system:
         this.trustStoreFile = trustStoreFile;
         // the password to the JSSE TrustStore:
         this.trustStorePw = trustStorePw.clone();
@@ -282,7 +282,7 @@ public final class LdapClientTrustStoreManager implements X509TrustManager, Seri
         InputStream result = ResourceUtil.getInputStream(trustStoreFile);
         if (null == result)
         {
-            throw new CertificateException("LdapClientTrustStoreManager.getTrustStoreInputStream file does not exist" );
+            throw new CertificateException("LdapClientTrustStoreManager.getTrustStoreInputStream file does not exist on fortress classpath" );
         }
         return result;
     }
@@ -82,7 +82,7 @@ public final class LdapClientTrustStoreManager implements X509TrustManager, Seri
                 "LdapClientTrustStoreManager constructor : input file name is null" );
         }
-        // contains the fully-qualified file name of a valid JSSE TrustStore on local file system:
+        // contains the file name of a valid JSSE TrustStore found on classpath:
         this.trustStoreFile = trustStoreFile;
         // the password to the JSSE TrustStore: